@@ -24,20 +24,19 @@
 ** Bug reports and questions can be sent to kde-devel@kde.org
 */
 
-#include "../config.h"
 #include "procbuf.h"
-#include <kprocess.h>
+#include <k3process.h>
 #include "kpackage.h"
 #include <klocale.h>
-#include <qlabel.h>
+#include <QtGui/QLabel>
 #include <kdebug.h>
 
 Modal::Modal(QString msg, QWidget *parent, const char * name )
-  : KDialog( parent, name, TRUE )
+  : KDialog( parent )
 {
   QLabel *line1 = new QLabel(msg,this);
-  line1->setAlignment(AlignCenter);
-  line1->setAutoResize(true);
+  line1->setAlignment(Qt::AlignCenter);
+  //line1->setAutoResize(true);
 
  }
 
@@ -60,19 +59,19 @@ procbuf::~procbuf()
 void procbuf::setup(QString cmd)
 {
   buf.truncate(0);
-  proc = new KProcess();
-  connect(proc, SIGNAL( receivedStdout(KProcess *, char *, int)), 
-			this, SLOT(slotReadInfo(KProcess *, char *, int)));
-  connect(proc, SIGNAL( receivedStderr(KProcess *, char *, int)), 
-			this, SLOT(slotReadInfo(KProcess *, char *, int)));
-  connect(proc, SIGNAL( processExited(KProcess *)), 
-			this, SLOT(slotExited(KProcess *)));
+  proc = new K3Process();
+  connect(proc, SIGNAL( receivedStdout(K3Process *, char *, int)), 
+			this, SLOT(slotReadInfo(K3Process *, char *, int)));
+  connect(proc, SIGNAL( receivedStderr(K3Process *, char *, int)), 
+			this, SLOT(slotReadInfo(K3Process *, char *, int)));
+  connect(proc, SIGNAL( processExited(K3Process *)), 
+			this, SLOT(slotExited(K3Process *)));
   proc->clearArguments();
   *proc << cmd;
   command = cmd;
 }
 
-void procbuf::slotReadInfo(KProcess *, char *buffer, int buflen)
+void procbuf::slotReadInfo(K3Process *, char *buffer, int buflen)
 {
    char last;
 
@@ -83,18 +82,18 @@ void procbuf::slotReadInfo(KProcess *, char *buffer, int buflen)
    buf += last;
 
    if (timed) {
-     timed =  FALSE;
+     timed =  false;
      tm->stop();
    }
 }
 
-void procbuf::slotExited(KProcess *)
+void procbuf::slotExited(K3Process *)
 {
   if (m) {
     m->terminate();
   }
   if (timed) {
-    timed =  FALSE;
+    timed =  false;
     tm->stop();
   }
 }
@@ -104,21 +103,21 @@ void procbuf::slotTimeout()
   if (m) {
     m->terminate();
   }
-  //  kdDebug() << "TTT\n";
+  //  kDebug() << "TTT\n";
 }
 
 int procbuf::start (QString  msg, bool errorDlg,
 		    int timeout, QString timeMsg )
 {
   if (timeout) {
-    tm->start(timeout*1000, TRUE);   
+    tm->start(timeout*1000);   
     timed = true;
   }
 
-  if (!proc->start(!msg.isNull() ? KProcess::NotifyOnExit : KProcess::Block,
-		   KProcess::All)) {
+  if (!proc->start(!msg.isNull() ? K3Process::NotifyOnExit : K3Process::Block,
+		   K3Process::All)) {
     if (errorDlg) {
-      KpMsgE(i18n("Kprocess Failure"),TRUE);
+      KpMsgE(i18n("Kprocess Failure"), true);
     }
     return 0;
   };
@@ -130,19 +129,19 @@ int procbuf::start (QString  msg, bool errorDlg,
     m = 0;
   }
 
-  kdDebug() << command 
+  kDebug() << command 
 	    << " dialog=" << errorDlg 
 	    << " normal=" << proc->normalExit()
 	    << " exit=" << proc->exitStatus() << endl;
   if (timed) {
-    kdDebug() << "timeout..................\n";
-    KpMsg("Error",i18n("Timeout: %1").arg(timeMsg), TRUE);
+    kDebug() << "timeout..................\n";
+    KpMsg("Error",i18n("Timeout: %1", timeMsg), true);
     delete proc; proc = 0;
     return 0;
   } else {
     if (!proc->normalExit() || proc->exitStatus()) {
       if (errorDlg) {
-	KpMsg("Error",i18n("Kprocess error:%1").arg(buf), TRUE);
+	KpMsg("Error",i18n("Kprocess error:%1", buf), true);
       }
       delete proc; proc = 0;
       return 0;
