@@ -17,34 +17,37 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
-** Bug reports and questions can be sent to kde-devel@kde.org
+** Bug reports and questions can be sent to <kde-devel@kde.org>
 */
 #include "Details.moc"
 
-#include <qlayout.h>
-#include <qhbox.h>
-#include <qvbox.h>
-#include <qwhatsthis.h>
-#include <qlabel.h>
-#include <ui.h>
+#include <QLayout>
 
-Details::Details(liloimage *lilo, QWidget *parent, const char *name, WFlags /* f */)
- : KDialogBase(parent, name, true, QString::null, Ok|Cancel, Ok, true)
+
+
+#include <QLabel>
+#include <ui.h>
+#include <kvbox.h>
+Details::Details(liloimage *lilo, QWidget *parent, const char *name, Qt::WFlags /* f */)
+ : KDialog(parent)
 {
 	l=lilo;
+	setButtons(Ok|Cancel);
+	setDefaultButton(Ok);
+	showButtonSeparator(true);
+        KVBox *page = new KVBox(this);
+	setMainWidget(page);
 
-        QVBox *page = makeVBoxMainWidget();
-
-	QHBox *vgab=new QHBox(page);
+	KHBox *vgab=new KHBox(page);
 	QLabel *vlbl=new QLabel(_("&Graphics mode on text console:"), vgab);
 	vga=new QComboBox(false, vgab);
 	vlbl->setBuddy(vga);
-	QWhatsThis::add(vgab, _("You can select the graphics mode for this kernel here.<br>If you intend to use a VGA graphics mode, you must compile the kernel with support for framebuffer devices. The <i>ask</i> setting brings up a prompt at boot time."));
+	vgab->setWhatsThis( _("You can select the graphics mode for this kernel here.<br>If you intend to use a VGA graphics mode, you must compile the kernel with support for framebuffer devices. The <i>ask</i> setting brings up a prompt at boot time."));
 	vga->insertItem(_("default"));
 	vga->insertItem(_("ask"));
 	vga->insertItem(_("text 80x25 (0)"));
@@ -73,25 +76,25 @@ Details::Details(liloimage *lilo, QWidget *parent, const char *name, WFlags /* f
 	vga->insertItem(_("VGA 1280x1024, 16.7M colors (795)"));
 	
 	readonly=new QCheckBox(_("Mount root filesystem &read-only"), page);
-	QWhatsThis::add(readonly, _("Mount the root filesystem for this kernel read-only. Since the init scripts normally take care of remounting the root filesystem in read-write mode after running some checks, this should always be turned on.<br>Don't turn this off unless you know what you're doing."));
+	readonly->setWhatsThis( _("Mount the root filesystem for this kernel read-only. Since the init scripts normally take care of remounting the root filesystem in read-write mode after running some checks, this should always be turned on.<br>Don't turn this off unless you know what you're doing."));
 
 	unsafe=new QCheckBox(_("Do not check &partition table"), page);
-	QWhatsThis::add(unsafe, _("This turns off some sanity checks while writing the configuration. This should not be used under \"normal\" circumstances, but it can be useful, for example, by providing the capability of booting from a floppy disk, without having a floppy in the drive every time you run lilo.<br>This sets the <i>unsafe</i> keyword in lilo.conf."));
+	unsafe->setWhatsThis( _("This turns off some sanity checks while writing the configuration. This should not be used under \"normal\" circumstances, but it can be useful, for example, by providing the capability of booting from a floppy disk, without having a floppy in the drive every time you run lilo.<br>This sets the <i>unsafe</i> keyword in lilo.conf."));
 
-	QHBox *opts=new QHBox(page);
+	KHBox *opts=new KHBox(page);
 	lock=new QCheckBox(_("&Record boot command lines for defaults"), opts);
-	QWhatsThis::add(lock, "<qt>" + _("Checking this box enables automatic recording of boot command lines as the default for the following bootups. This way, lilo \"locks\" on a choice until it is manually overridden.<br>This sets the <b>lock</b> option in lilo.conf"));
+	lock->setWhatsThis( "<qt>" + _("Checking this box enables automatic recording of boot command lines as the default for the following bootups. This way, lilo \"locks\" on a choice until it is manually overridden.<br>This sets the <b>lock</b> option in lilo.conf"));
 	restricted=new QCheckBox(_("R&estrict parameters"), opts);
 	connect(restricted, SIGNAL(clicked()), SLOT(check_pw()));
-	QWhatsThis::add(restricted, _("If this box is checked, a password (entered below) is required only if any parameters are changed (i.e. the user can boot <i>linux</i>, but not <i>linux single</i> or <i>linux init=/bin/sh</i>).\nThis sets the <b>restricted</b> option in lilo.conf."));
+	restricted->setWhatsThis( _("If this box is checked, a password (entered below) is required only if any parameters are changed (i.e. the user can boot <i>linux</i>, but not <i>linux single</i> or <i>linux init=/bin/sh</i>).\nThis sets the <b>restricted</b> option in lilo.conf."));
 
-	QHBox *pw=new QHBox(page);
+	KHBox *pw=new KHBox(page);
 	use_password=new QCheckBox(_("Require &password:"), pw);
 	connect(use_password, SIGNAL(clicked()), SLOT(check_pw()));
 	password=new QLineEdit(pw);
 	password->setMaxLength(15);
 	password->setEchoMode(QLineEdit::Password);
-	QWhatsThis::add(pw, _("Enter the password required for bootup (if any) here. If <i>restricted</i> above is checked, the password is required for additional parameters only.<br><b>WARNING:</b> The password is stored in clear text in /etc/lilo.conf. You'll want to make sure nobody untrusted can read this file. Also, you probably don't want to use your normal/root password here."));
+	pw->setWhatsThis( _("Enter the password required for bootup (if any) here. If <i>restricted</i> above is checked, the password is required for additional parameters only.<br><b>WARNING:</b> The password is stored in clear text in /etc/lilo.conf. You'll want to make sure nobody untrusted can read this file. Also, you probably don't want to use your normal/root password here."));
 
 	if(l) {
 		QString mode=l->get("vga", "").cstr();
@@ -101,7 +104,7 @@ Details::Details(liloimage *lilo, QWidget *parent, const char *name, WFlags /* f
 			vga->setCurrentItem(1);
 		else
 			for(int i=0; i<vga->count(); i++) {
-				if(vga->text(i).contains("(" + mode + ")")) {
+				if(vga->text(i).contains('(' + mode + ')')) {
 					vga->setCurrentItem(i);
 					break;
 				}
